
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Declarations
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(def id
  (; (| (- a z) (- A Z))
     (* (| (- a z) (- A Z) (- 0 9) '_))))

(def data
  (; (+ (- 0 9))
     (? (; '. (+ (- 0 9))))
     (? (; (? '\ ) (| 'e 'E) (? '-) (+ (- 0 9)))))
  (; '\" (* (| '\  '! (- # }))) '\")
  (; '` (- \  }) '\'))

(def texmacs
  '\\frac{ '\\sqrt{ '\\rsub{ '\\rsup{ '\\matrix{ '\\row{
  '\\set{ '\\reset{ '}{ '})

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Main lexing routine
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(main
      ;; TeXmacs typesetting command
      (texmacs ($ ($)))

      ;; Assignments
      ('== ($ ($)))
      ('\:= ($ ($)))
      ('+= ($ ($)))
      ('-= ($ ($)))
      ('*= ($ ($)))
      ('/= ($ ($)))
      ('%= ($ ($)))

      ;; Mapping
      ((| '-> '<into>) ($ (->)))
      ((| '\:-> '<mapsto>) ($ (\:->)))

      ;; Typing
      ('\: ($ ($)))

      ;; Flux
      ('<ll> ($ (<<)))
      ('<gg> ($ (>>)))

      ;; Logical tokens
      ((| 'or '<vee>) ($ (or)))
      ('xor ($ (xor)))
      ((| 'and '<wedge>) ($ (and)))
      ((| 'not '<neg>) ($ (not)))

      ;; Relation token
      ('= ($ ($)))
      ('<less> ($ (<)))
      ((| '<leq> '<leqslant>) ($ (<=)))
      ('<gtr> ($ ($)))
      ((| '<geq> '<geqslant>) ($ (>=)))
      ('<neq> ($ (!=)))
      ('<nless> ($ (!<)))
      ((| '<nleq> '<nleqslant>) ($ (!<=)))
      ('<ngtr> ($ (!>)))
      ((| '<ngeq> '<ngeqslant>) ($ (!>=)))

      ;; arithmetic tokens
      ('+ ($ ($)))
      ('<oplus> ($ (@+)))
      ('- ($ ($)))
      ('<ominus> ($ (@-)))
      ('* ($ ($)))
      ('<otimes> ($ (@*)))
      ('/ ($ ($)))
      ('<oover> ($ (@/)))
      ('% ($ ($)))

      ;; script tokens
      ('^ ($ ($)))
      ('._ ($ (_)))

      ;; unary operator tokens
      ('++ ($ ($)))
      ('-- ($ ($)))
      ('\' ($ ($)))
      ('! ($ ($)))
      ('~ ($ ($)))

      ;; access token
      ('. ($ ($)))

      ;; delimiter tokens
      ((| '\( '<left-\(>) (\( ($)))
      ((| '\) '<right-\)>) (\) ($)))
      ((| '\\{ '<left-\\{>) (lacc ($)))
      ((| '\\} '<right-\\}>) (racc ($)))
      ((| '[ '<left-[>) ([ ($)))
      ((| '] '<right-]>) (] ($)))
      (', ($ ($)))
      ('; ($ ($)))

      ;; identifiers and data
      (id ($ (id)))
      (data ($ (data)))

      ('# () misc)

      ;; control characters
      ('\  ())
      ('\t ())
      ('\n ())
      (<eof> ()))
