
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : keymaps.scm
;; DESCRIPTION : setup key combinations for frequently used commands
;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
;;
;; This software falls under the GNU general public licence and comes WITHOUT
;; ANY WARRENTY WHATSOEVER. See the file $TEXMACS_PATH/LICENCE for details.
;; If you don't have this file, write to the Free Software Foundation, Inc.,
;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(set-keymap '(text math prog)
  '(("<shift-spc>" (insert-string " "))
    ("<return>" (if (is-deactivated) (activate) (insert-return)))
    ("<shift-return>" (insert-return))
    ("<del>" (back-space))
    ("<shift-del>" (back-space))
    ("<ctrl-del>" (remove-object))
    ("<left>" (go-left))
    ("<right>" (go-right))
    ("<up>" (go-up))
    ("<down>" (go-down))
    ("<page-down>" (go-page-down))
    ("<page-up>" (go-page-up))
    ("<home>" (go-home-line))
    ("<end>" (go-end-line))
    ("<shift-home>" (go-home))
    ("<shift-end>" (go-end))
    ("<ctrl-home>" (selection-set-start))
    ("<ctrl-end>" (selection-set-end))
    ("<esc>r" (selection-clear))
    ("<alt-spc>" (make-space "0.2spc"))
    ("<alt-del>" (make-space "-0.2spc"))
    ("<tab>" (if (or (is-deactivated) (in-preamble-mode))
               (insert-argument) (make-htab "5mm")))
    ("<esc>&" (make-format "line separator"))
    ("<esc>:" (make-format "line break"))
    ("<esc>;" (make-format "new line"))
    ("<esc><return>" (make-format "next line"))
    ("<esc>/" (make-format "no line break"))

    ("<esc><esc>\\" (insert-string "\\"))
    ("<esc><esc>$" (insert-string "$"))
    ("<esc><esc>&" (insert-string "&"))
    ("<esc><esc>" (insert-string ""))
    ("<esc><esc>#" (insert-string "#"))
    ("<esc><esc>" (insert-string ""))
    ("<esc><esc>%" (insert-string "%"))
    ("<esc><esc><esc>" (begin))

    ("<F1>" (new-buffer))
    ("<F2>" (choose-file "Load file" "" 'load-generic-buffer))
    ("<F3>" (save-texmacs-buffer (get-name-buffer)))
    ("<F4>" (choose-file "Save TeXmacs file" "TeXmacs" 'save-texmacs-buffer))
    ("<esc>K" (kill-buffer))
    ("<esc>Q"
      (if (exists-unsaved-buffer)
	(interactive
          '("There are unsaved files. Really quit?")
          'quit-TeXmacs-confirm)
	(quit-TeXmacs)))
    ("<esc>c" (copy))
    ("<esc>u" (cut))
    ("<esc>p" (paste))

    ("\\" (make-hybrid))
    ("<esc>$" (make-symbol))
    ("<esc>\\" (make-latex))
    ("<esc>q" (make-quote))
    ("<esc>d" (make-delay))
    ("<esc>=" (make-assign))
    ("<esc>s" (interactive '("Set:") 'make-set))
    ("<esc><less>" (make-apply))
    ("<esc>b" (make-active-begin-from-apply))
    ("<esc>m" (make-macro))
    ("<esc>f" (make-function))
    ("<esc>e" (make-environment))
    ("<esc>g" (make-group))
    ("<esc>!" (make-label))
    ("<esc>?" (make-reference))
    ("<esc>w" (make-write))
    ("<esc>+" (make-plus))
    ("<esc>-" (make-minus))
    ("<esc>x" (make-times))
    ("<esc>*" (make-merge))
    ("<esc>#" (make-number))
    ("<esc><gtr>" (make-translate))

    ("<esc><left>"
      (if (inside-tree) (branch-insert #f) (column-insert #f)))
    ("<esc><right>"
      (if (inside-tree) (branch-insert #t) (column-insert #t)))
    ("<esc><up>" (row-insert #f))
    ("<esc><down>" (row-insert #t))
    ("<shift-left>"
      (if (inside-tree) (branch-insert #f) (column-insert #f)))
    ("<shift-right>"
      (if (inside-tree) (branch-insert #t) (column-insert #t)))
    ("<shift-up>" (row-insert #f))
    ("<shift-down>" (row-insert #t))
    ("<ctrl-left" (mosaic-horizontal "<"))
    ("<ctrl-right>" (mosaic-horizontal ">"))
    ("<ctrl-up>" (mosaic-vertical "<"))
    ("<ctrl-down>" (mosaic-vertical ">"))
    ("<alt-right>" (mosaic-glue "r"))
    ("<alt-down>" (mosaic-glue "d"))))

(set-keymap '(text)
  '(("$" (make-active-set "mode" "math"))
    ("" (make-active-set "mode" "prog"))
    ("<less>" (insert-string "<less>"))
    ("<gtr>" (insert-string "<gtr>"))
    ("<esc>I" (make-active-list "itemize"))
    ("<esc>E" (make-active-list "enumerate"))
    ("<esc>N" (make-active-item "item"))
    ("<esc>L" (make-session "TeXmacs lisp"))
    ("<esc>S" (make-session "scheme"))
    ("<esc><ctrl-s>" (make-active-set "font family" "ss"))
    ("<esc><ctrl-t>" (make-active-set "font family" "tt"))
    ("<esc><ctrl-b>" (make-active-set "font series" "bold"))
    ("<esc><ctrl-m>" (make-active-set "font series" "medium"))
    ("<esc><ctrl-r>" (make-active-set "font shape" "right"))
    ("<esc><ctrl-i>" (make-active-set "font shape" "italic"))
    ("<esc><ctrl-l>" (make-active-set "font shape" "slanted"))
    ("<esc><ctrl-p>" (make-active-set "font shape" "small-caps"))))

(set-keymap '(math)
  '(("$" (make-active-set "mode" "text"))
    ("<esc><ctrl-R>" (make-active-set "math font" "roman"))
    ("<esc><ctrl-K>" (make-active-set "math font" "concrete"))
    ("<esc><ctrl-F>" (make-active-set "math font" "Euler"))
    ("<esc><ctrl-E>" (make-active-set "math font" "ENR"))
    ("<esc><ctrl-C>" (make-active-set "math font" "cal"))
    ("<esc><ctrl-B>" (make-active-set "math font" "Bbb*"))
    ("<esc><ctrl-o>" (make-active-set "math font family" "mr"))
    ("<esc><ctrl-s>" (make-active-set "math font family" "ms"))
    ("<esc><ctrl-t>" (make-active-set "math font family" "mt"))
    ("<esc><ctrl-m>" (make-active-set "math font series" "medium"))
    ("<esc><ctrl-b>" (make-active-set "math font series" "bold"))
    ("<esc><ctrl-n>" (make-active-set "math font shape" "normal"))
    ("<esc><ctrl-r>" (make-active-set "math font shape" "right"))
    ("<esc><ctrl-l>" (make-active-set "math font shape" "slanted"))
    ("<esc><ctrl-i>" (make-active-set "math font shape" "italic"))
    ("<esc><ctrl-u>" (make-active-set "math font shape" "semi-right"))
    ("_" (make-script #f #t))
    ("^" (make-script #t #t))
    ("<esc>~" (make-wide "~"))
    ("<esc>^" (make-wide "^"))
    ("<esc>B" (make-wide "<bar>"))
    ("<esc>V" (make-wide "<vect>"))
    ("<esc>v" (make-wide "<check>"))
    ("<esc>U" (make-wide "<breve>"))
    ("<esc>'" (make-wide "<acute>"))
    ("<esc>`" (make-wide "<grave>"))
    ("<esc>L_" (make-script #f #f))
    ("<esc>L^" (make-script #t #f))
    ("<esc>F" (make-fraction))
    ("<esc>/" (make-fraction))
    ("<esc>S" (make-sqrt))
    ("<esc>R" (make-var-sqrt))
    ("<esc>N" (make-neg))
    ("<esc>A" (make-tree))
    ("<esc>M" (make-matrix))
    ("<esc>T" (make-table))))

(set-keymap '(prog)
  '(("<less>" (insert-string "<less>"))
    ("<gtr>" (insert-string "<gtr>"))
    ("" (make-active-set "mode" "text"))
    ("<return>" (if (in-input-mode)
		    (set-output (prog-eval (get-input)))
		    (insert-return)))
    ("<esc>C" (set-output (edit-lisp-compile (get-input))))
    ("<esc>E" (set-output (edit-lisp-eval (get-input))))))
