
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : latex.scm
;; DESCRIPTION : setup key combinations for frequently used commands
;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
;;
;; This software falls under the GNU general public licence and comes WITHOUT
;; ANY WARRENTY WHATSOEVER. See the file $TEXMACS_PATH/LICENCE for details.
;; If you don't have this file, write to the Free Software Foundation, Inc.,
;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(set-latex-commands
  '(("#" "Insert sharp" (insert-string "#"))
    ("$" "Insert dollar" (insert-string "$"))
    ("(" "Insert formula" (make-active-set "mode" "math"))
    ("[" "Insert equation" (make-active-begin "equation*"))
    ("," "Insert small horizontal space" (make-space "0.2spc"))
    (":" "Insert medium horizontal space" (make-space "0.4spc"))
    (";" "Insert thick horizontal space" (make-space "0.6spc"))
    (" " "Insert horizontal interword space" (make-space "1spc"))
    ("!" "Insert negative horizontal space" (make-space "-0.2spc"))

    ("cC" "Make " (emulate-keyboard "<esc>cC"))
    ("cc" "Make " (emulate-keyboard "<esc>cc"))
    ("\'E" "Insert " (emulate-keyboard "<esc>\'E"))
    ("\'e" "Insert " (emulate-keyboard "<esc>\'e"))
    ("`A" "Insert " (emulate-keyboard "<esc>`A"))
    ("`E" "Insert " (emulate-keyboard "<esc>`E"))
    ("`U" "Insert " (emulate-keyboard "<esc>`U"))
    ("`a" "Insert " (emulate-keyboard "<esc>`a"))
    ("`e" "Insert " (emulate-keyboard "<esc>`e"))
    ("`u" "Insert " (emulate-keyboard "<esc>`u"))
    ("oe" "Insert " (emulate-keyboard "<alt-o><alt-e>"))
    ("ae" "Insert " (emulate-keyboard "<alt-a>"))
    ("ss" "Insert " (emulate-keyboard "<alt-s>"))
    ("^A" "Insert " (emulate-keyboard "<esc>^A"))
    ("^E" "Insert " (emulate-keyboard "<esc>^E"))
    ("^I" "Insert " (emulate-keyboard "<esc>^I"))
    ("^O" "Insert " (emulate-keyboard "<esc>^O"))
    ("^U" "Insert " (emulate-keyboard "<esc>^U"))
    ("^a" "Insert " (emulate-keyboard "<esc>^a"))
    ("^e" "Insert " (emulate-keyboard "<esc>^e"))
    ("^i" "Insert " (emulate-keyboard "<esc>^i"))
    ("^o" "Insert " (emulate-keyboard "<esc>^o"))
    ("^u" "Insert " (emulate-keyboard "<esc>^u"))
    ("OE" "Insert SS" (emulate-keyboard "<alt-O><alt-E>"))
    ("AE" "Insert SS" (emulate-keyboard "<alt-A>"))
    ("SS" "Insert SS" (emulate-keyboard "<alt-S>"))

    ("arccos" "Insert arccos" (insert-string "arccos"))
    ("arcsin" "Insert arcsin" (insert-string "arcsin"))
    ("arctan" "Insert arctan" (insert-string "arctan"))
    ("arg" "Insert arg" (insert-string "arg"))
    ("cos" "Insert cos" (insert-string "cos"))
    ("cosh" "Insert cosh" (insert-string "cosh"))
    ("cot" "Insert cot" (insert-string "cot"))
    ("coth" "Insert coth" (insert-string "coth"))
    ("csc" "Insert csc" (insert-string "csc"))
    ("deg" "Insert deg" (insert-string "deg"))
    ("det" "Insert det" (insert-string "det"))
    ("dim" "Insert dim" (insert-string "dim"))
    ("exp" "Insert exp" (insert-string "exp"))
    ("gcd" "Insert gcd" (insert-string "gcd"))
    ("hom" "Insert hom" (insert-string "hom"))
    ("inf" "Insert inf" (insert-string "inf"))
    ("ker" "Insert ker" (insert-string "ker"))
    ("lg" "Insert lg" (insert-string "lg"))
    ("lim" "Insert lim" (insert-string "lim"))
    ("liminf" "Insert liminf" (insert-string "liminf"))
    ("limsup" "Insert limsup" (insert-string "limsup"))
    ("ln" "Insert ln" (insert-string "ln"))
    ("log" "Insert log" (insert-string "log"))
    ("max" "Insert max" (insert-string "max"))
    ("min" "Insert min" (insert-string "min"))
    ("Pr" "Insert Pr" (insert-string "Pr"))
    ("sec" "Insert sec" (insert-string "sec"))
    ("sin" "Insert sin" (insert-string "sin"))
    ("sinh" "Insert sinh" (insert-string "sinh"))
    ("sup" "Insert sup" (insert-string "sup"))
    ("tan" "Insert tan" (insert-string "tan"))
    ("tanh" "Insert tanh" (insert-string "tanh"))

    ("appendix" "Insert appendix" (make-apply-arg "appendix"))
    ("chapter" "Insert chapter" (make-apply-arg "chapter"))
    ("section" "Insert section" (make-apply-arg "section"))
    ("subsection" "Insert subsection" (make-apply-arg "subsection"))
    ("subsubsection" "Insert subsubsection" (make-apply-arg "subsubsection"))

    ("frac" "Make fraction" (make-fraction))
    ("sqrt" "Make square root" (make-sqrt))
    ("not" "Make negation" (make-neg))
    ("acute" "Make acute" (make-wide "<acute>"))
    ("bar" "Make bar" (make-wide "<bar>"))
    ("breve" "Make bar" (make-wide "<breve>"))
    ("check" "Make check" (make-wide "<check>"))
    ("grave" "Make grave" (make-wide "<grave>"))
    ("hat" "Make hat" (make-wide "^"))
    ("tilde" "Make tilde" (make-wide "~"))
    ("vect" "Make vector" (make-wide "<vect>"))
    ("widecheck" "Make check" (make-wide "<check>"))
    ("widehat" "Make hat" (make-wide "^"))
    ("widetilde" "Make tilde" (make-wide "~"))

    ("sum" "Insert big summation" (insert-string "<big-sum>"))
    ("prod" "Insert big product" (insert-string "<big-prod>"))
    ("coprod" "Insert big coproduct" (insert-string "<big-amalg>"))
    ("int" "Insert big integral" (insert-string "<big-int>"))
    ("oint" "Insert big contour integral" (insert-string "<big-oint>"))
    ("bigcap" "Insert big intersection" (insert-string "<big-cap>"))
    ("bigcup" "Insert big union" (insert-string "<big-cup>"))
    ("bigsqcup" "Insert big square union" (insert-string "<big-sqcup>"))
    ("bigvee" "Insert big logical or" (insert-string "<big-vee>"))
    ("bigwedge" "Insert big logical and" (insert-string "<big-wedge>"))
    ("bigodot" "Insert big dotted point" (insert-string "<big-odot>"))
    ("bigotimes" "Insert big tensor product" (insert-string "<big-otimes>"))
    ("bigoplus" "Insert big direct sum" (insert-string "<big-oplus>"))
    ("biguplus" "Insert big union sum" (insert-string "<big-uplus>"))

    ("left(" "Insert large (" (insert-string "<left-(>"))
    ("left)" "Insert large left )" (insert-string "<left-)>"))
    ("left[" "Insert large [" (insert-string "<left-[>"))
    ("left]" "Insert large left ]" (insert-string "<left-]>"))
    ("left{" "Insert large {" (insert-string "<left-{>"))
    ("left}" "Insert large left }" (insert-string "<left-}>"))
    ("leftlfloor" "Insert large <lfloor>" (insert-string "<left-lfloor>"))
    ("leftrfloor" "Insert large left <rfloor>" (insert-string "<left-rfloor>"))
    ("leftlceil" "Insert large <lceil>" (insert-string "<left-lceil>"))
    ("leftrceil" "Insert large left <rceil>" (insert-string "<left-rceil>"))
    ("leftlangle" "Insert large <langle>" (insert-string "<left-langle>"))
    ("leftrangle" "Insert large left <rangle>" (insert-string "<left-rangle>"))
    ("left|" "Insert large left <mid>" (insert-string "<left-|>"))
    ("left||" "Insert large left <parallel>" (insert-string "<left-||>"))
    ("left/" "Insert large left /" (insert-string "<left-/>"))
    ("leftbackslash" "Insert large left \\" (insert-string "<left-\\>"))

    ("right(" "Insert large right (" (insert-string "<right-(>"))
    ("right)" "Insert large )" (insert-string "<right-)>"))
    ("right[" "Insert large right [" (insert-string "<right-[>"))
    ("right]" "Insert large ]" (insert-string "<right-]>"))
    ("right{" "Insert large right {" (insert-string "<right-{>"))
    ("right}" "Insert large }" (insert-string "<right-}>"))
    ("rightlfloor" "Insert large right <lfloor>"
      (insert-string "<right-lfloor>"))
    ("rightrfloor" "Insert large <rfloor>" (insert-string "<right-rfloor>"))
    ("rightlceil" "Insert large right <lceil>" (insert-string "<right-lceil>"))
    ("rightrceil" "Insert large <rceil>" (insert-string "<right-rceil>"))
    ("rightlangle" "Insert large right <langle>"
      (insert-string "<right-langle>"))
    ("rightrangle" "Insert large <rangle>" (insert-string "<right-rangle>"))
    ("right|" "Insert large right <mid>" (insert-string "<right-|>"))
    ("right||" "Insert large right <parallel>" (insert-string "<right-||>"))
    ("right/" "Insert large right /" (insert-string "<right-/>"))
    ("rightbackslash" "Insert large right \\" (insert-string "<right-\\>"))

    ("rmfamily" "Use roman font family" (make-active-set "font family" "rm"))
    ("ttfamily" "Use typewriter font family"
      (make-active-set "font family" "tt"))
    ("sffamily" "Use sans serif font family"
      (make-active-set "font family" "sf"))
    ("mdseries" "Use medium font series"
      (make-active-set "font series" "medium"))
    ("bfseries" "Use bold font series" (make-active-set "font series" "bold"))
    ("upshape" "Use right font shape" (make-active-set "font shape" "right"))
    ("itshape" "Use italic font shape" (make-active-set "font shape" "italic"))
    ("slshape" "Use slanted font shape"
      (make-active-set "font shape" "slanted"))
    ("scshape" "Use small-caps font shape"
      (make-active-set "font shape" "small-caps"))
    ("rm" "Use roman font family" (make-active-set "font family" "rm"))
    ("tt" "Use typewriter font family" (make-active-set "font family" "tt"))
    ("sf" "Use sans serif font family" (make-active-set "font family" "sf"))
    ("md" "Use medium font series" (make-active-set "font series" "medium"))
    ("bf" "Use bold font series" (make-active-set "font series" "bold"))
    ("up" "Use right font shape" (make-active-set "font shape" "right"))
    ("it" "Use italic font shape" (make-active-set "font shape" "italic"))
    ("em" "Use italic font shape" (make-active-set "font shape" "italic"))
    ("sl" "Use slanted font shape" (make-active-set "font shape" "slanted"))
    ("sc" "Use small-caps font shape"
      (make-active-set "font shape" "small-caps"))
    ("textrm" "Use roman font family"
      (make-active-set "font family" "rm"))
    ("texttt" "Use typewriter font family"
      (make-active-set "font family" "tt"))
    ("textsf" "Use sans serif font family"
      (make-active-set "font family" "sf"))
    ("textmd" "Use medium font series"
      (make-active-set "font series" "medium"))
    ("textbf" "Use bold font series" (make-active-set "font series" "bold"))
    ("textup" "Use right font shape" (make-active-set "font shape" "right"))
    ("textit" "Use italic font shape" (make-active-set "font shape" "italic"))
    ("emph" "Use italic font shape" (make-active-set "font shape" "italic"))
    ("textsl" "Use slanted font shape"
      (make-active-set "font shape" "slanted"))
    ("textsc" "Use small-caps font shape"
      (make-active-set "font shape" "small-caps"))
    ("cal" "Use calligraphic font" (make-active-set "math font" "cal"))
    ("frak" "Use fraktur font" (make-active-set "math font" "Euler"))
    ("Bbb" "Use blackboard bold font" (make-active-set "math font" "Bbb*"))
    ("mathcal" "Use calligraphic font" (make-active-set "math font" "cal"))
    ("mathfrak" "Use fraktur font" (make-active-set "math font" "Euler"))
    ("mathbb" "Use blackboard math font"
      (make-active-set "math font" "Bbb*"))
    ("mathrm" "Use roman font family"
      (make-active-set "math font family" "rm"))
    ("mathtt" "Use typewriter font family"
      (make-active-set "math font family" "tt"))
    ("mathsf" "Use sans serif font family"
      (make-active-set "math font family" "sf"))
    ("mathmd" "Use medium font series"
      (make-active-set "math font series" "medium"))
    ("mathbf" "Use bold font series"
      (make-active-set "math font series" "bold"))
    ("mathup" "Use right font shape"
      (make-active-set "math font shape" "right"))
    ("mathit" "Use italic font shape"
      (make-active-set "math font shape" "italic"))
    ("tiny" "Use tiny font font size" (make-active-set "font size" "0.59"))
    ("scriptsize" "Use script font size" (make-active-set "font size" "0.71"))
    ("footnotesize" "Use footnote font size"
      (make-active-set "font size" "0.71"))
    ("small" "Use small font size" (make-active-set "font size" "0.84"))
    ("normalsize" "Use normal font size" (make-active-set "font size" "1"))
    ("large" "Use large font size" (make-active-set "font size" "1.19"))
    ("Large" "Use very large font size" (make-active-set "font size" "1.41"))
    ("LARGE" "Use very large font size" (make-active-set "font size" "1.41"))
    ("huge" "Use huge font size" (make-active-set "font size" "1.68"))
    ("Huge" "Use really huge font size" (make-active-set "font size" "2"))
    ("displaystyle" "Switch to formula style"
      (make-active-set "formula style" "true"))

    ("black" "Use a black color" (make-active-set "color" "black"))
    ("white" "Use a white color" (make-active-set "color" "white"))
    ("grey" "Use a grey color" (make-active-set "color" "grey"))
    ("red" "Use a red color" (make-active-set "color" "red"))
    ("blue" "Use a blue color" (make-active-set "color" "blue"))
    ("yellow" "Use a yellow color" (make-active-set "color" "yellow"))
    ("green" "Use a green color" (make-active-set "color" "green"))
    ("orange" "Use a orange color" (make-active-set "color" "orange"))
    ("magenta" "Use a magenta color" (make-active-set "color" "magenta"))
    ("brown" "Use a brown color" (make-active-set "color" "brown"))
    ("pink" "Use a pink color" (make-active-set "color" "pink"))

    ("smallskip" "Insert small vertical space" (make-vspace-after "0.5fn"))
    ("medskip" "Insert medium vertical space" (make-vspace-after "1fn"))
    ("bigskip" "Insert big vertical space" (make-vspace-after "2fn"))
    ("item" "Insert new item or number" (make-active-item "item"))
    ("label" "Make label" (make-label))
    ("ref" "Make reference" (make-reference))))

(set-latex-symbols
  '("alpha" "beta" "gamma" "delta" "epsilon"
    "zeta" "eta" "theta" "iota" "kappa"
    "lambda" "mu" "nu" "xi" "omicron" "pi" "rho"
    "sigma" "tau" "upsilon" "phi" "chi"
    "psi" "omega" "varepsilon" "vartheta"
    "varpi" "varrho" "varsigma" "varphi"
    "leftharpoonup" "leftharpoondown"
    "rightharpoonup" "rightharpoondown" "lefthook" "righthook"
    "triangleright" "triangleleft" "star" "partial"
    "flat" "natural" "sharp" "smile" "frown" "ell"
    "imath" "jmath" "wp" "vect"

    "Alpha" "Beta" "Gamma" "Delta" "Epsilon"
    "Zeta" "Eta" "Theta" "Iota" "Kappa" "Lambda"
    "Mu" "Nu" "Xi" "Omicron" "Pi" "Rho"
    "Sigma" "Tau" "Upsilon" "Phi" "Chi" "Psi" "Omega"
    "grave" "acute" "check" "breve" "bar"
    "cedille" "sz" "ae" "oe" "AE" "OE"
    "asterisk" "dot" "ddot"

    "cdot" "times" "asterisk" "div" "diamond"
    "pm" "mp" "oplus" "ominus" "otimes" "oslash"
    "odot" "bigcirc" "circ" "bullet" "asymp" "equiv"
    "subseteq" "supseteq" "leq" "geq" "preceq" "succeq"
    "sim" "approx" "subset" "supset" "ll" "gg"
    "prec" "succ" "leftarrow" "rightarrow" "uparrow"
    "downarrow" "leftrightarrow" "nearrow" "searrow"
    "simeq" "Leftarrow" "Rightarrow" "Uparrow"
    "Downarrow" "Leftrightarrow" "nwarrow" "swarrow"
    "propto" "infty" "in" "ni" "bigtriangleup"
    "bigtriangledown" "negate" "varshortmid" "forall" "exists"
    "neg" "emptyset" "Re" "Im" "top" "bot" "aleph" "perp"
    "cup" "cap" "uplus" "wedge" "vee" "vdash" "dashv"
    "lfloor" "rfloor" "lceil" "rceil" "langle" "rangle"
    "updownarrow" "Updownarrow" "wr" "sqrt" "amalg" "nabla"
    "sqcup" "sqcap" "sqsubseteq" "sqsupseteq" "paragraph" "dag" "ddag"
    "endofline" "clubsuit" "diamondsuit" "heartsuit" "spadesuit" "backslash"

    "boxdot" "boxplus" "boxtimes" "box" "blacksquare"
    "centerdot" "lozenge" "blacklozenge" "circlearrowright"
    "circlearrowleft" "rightleftharpoons" "leftrightharpoons"
    "boxminus" "Vdash" "Vvdash" "dashV" "twoheadrightarrow"
    "twoheadleftarrow" "leftleftarrows" "rightrightarrows"
    "upuparrows" "downdownarrows" "upharpoonright"
    "downharpoonright" "upharpoonleft" "downharpoonleft"
    "rightarrowtail" "leftarrowtail" "leftrightarrows"
    "rightleftarrows" "Lsh" "Rsh" "rightsquigarrow"
    "leftrightsquigarrow" "looparrowleft" "looparrowright"
    "circeq" "succsim" "gtrsim" "gtrapprox" "multimap"
    "therefore" "because" "doteqdot" "triangleq"
    "precsim" "lesssim" "lessapprox" "eqslantless"
    "eqslantgtr" "curlyeqprec" "curlyeqsucc" "preccurlyeq"
    "leqq" "leqslant" "lessgtr" "smalldash"
    "risingdoteq" "fallingdoteq" "succcurlyeq" "geqq"
    "geqslant" "gtrless" "sqsubset" "sqsupset"
    "vartriangleright" "vartriangleleft" "trianglerighteq"
    "trianglelefteq" "blackstar" "between"
    "blacktriangledown" "blacktriangleright" "blacktriangleleft"
    "shortrightarrow" "shortleftarrow" "triangle"
    "blacktriangleup" "triangledown" "eqcirc"
    "lesseqgtr" "gtreqless" "lesseqqgtr" "gtreqqless"
    "yen" "Rrightarrow" "Lleftarrow" "checkmark"
    "veebar" "barwedge" "doublebarwedge" "angle" "measuredangle"
    "sphericalangle" "propto" "smile" "frown" "Subset"
    "Supset" "Cup" "Cap" "curlyvee" "curlywedge"
    "leftthreetimes" "rightthreetimes" "subseteqq" "supseteqq"
    "bumpeq" "Bumpeq" "lll" "ggg" "ulcorner" "urcorner"
    "circledR" "circledS" "pitchfork" "dotplus" "backsim"
    "backsimeq" "llcorner" "lrcorner" "maltese"
    "complement" "intercal" "circledcirc" "circledast" "circledminus"

    "lvertneqq" "gvertneqq" "nleq" "ngeq" "nless" "ngtr"
    "nprec" "nsucc" "lneqq" "gneqq" "nleqslant" "ngeqslant"
    "lneq" "gneq" "npreceq" "nsucceq" "precnsim"
    "succnsim" "lnsim" "gnsim" "nleqq" "ngeqq"
    "precneqq" "succneqq" "precnapprox" "succnapprox"
    "lnapprox" "gnapprox" "nsim" "ncong" "dslash"
    "dbackslash" "varsubsetneq" "varsupsetneq"
    "nsubseteqq" "nsupseteqq" "subsetneqq" "supsetneqq"
    "varsubsetneqq" "varsupsetneqq" "subsetneq" "supsetneq"
    "nsubseteq" "nsupseteq" "nparallel" "nmid" "nshormid"
    "nshortparallel" "nvdash" "nVdash" "nvDash" "nVDash"
    "ntriangleqright" "ntriangleqleft" "ntriangleleft"
    "ntriangleright" "nleftarrow" "nrightarrow" "nLeftarrow"
    "nRightarrow" "nLeftrightarrow" "nleftrightarrow"
    "divideontimes" "varnothing" "nexists"
    "mho" "thorn" "eqsim" "beth" "gimel" "daleth"
    "lessdot" "gtrdot" "ltimes" "rtimes" "shortmid"
    "shortparallel" "smallsetminus" "thicksim" "thickapprox"
    "approxeq" "succapprox" "precapprox" "curvearrowleft"
    "curvearrowright" "digamma" "varkappa" "" "hslash"
    "hbar" "backepsilon"

    "mapsto" "longmapsto" "longrightarrow" "longleftarrow"
    "longleftrightarrow" "longRightarrow" "longLeftarrow"
    "longLeftrightarrow" "ldots" "cdots" "vdots" "ddots"))
