
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : main-menu.scm
;; DESCRIPTION : the default main menu of TeXmacs
;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
;;
;; This software falls under the GNU general public licence and comes WITHOUT
;; ANY WARRENTY WHATSOEVER. See the file $TEXMACS_PATH/LICENCE for details.
;; If you don't have this file, write to the Free Software Foundation, Inc.,
;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; General commands

(define setup-printer
  (lambda (cmd type dpi)
    (set-printing-command cmd)
    (set-printer-page-type type)
    (set-printer-dpi dpi)))

(define load-texmacs-buffer (lambda (s) (load-buffer s "TeXmacs")))
(define save-texmacs-buffer (lambda (s) (save-buffer s "TeXmacs")))
(define load-latex-buffer (lambda (s) (load-buffer s "latex")))
(define save-latex-buffer (lambda (s) (save-buffer s "latex")))
(define load-html-buffer (lambda (s) (load-buffer s "html")))
(define save-html-buffer (lambda (s) (save-buffer s "html")))
(define load-verbatim-buffer (lambda (s) (load-buffer s "verbatim")))
(define save-verbatim-buffer (lambda (s) (save-buffer s "verbatim")))
(define load-help-buffer (lambda (s) (load-buffer s "help")))
(define load-in-new-window (lambda (s) (load-generic-buffer-into s 1)))

(define get-env
  (lambda (s)
    (tree->string (get-env-tree s))))

;; Commands for insertions

(define make-apply-arg
  (lambda (s)
    (make-apply)
    (insert-string s)
    (insert-argument)
    (set-message "Press <Return> to activate" s)))

(define make-active-aux
  (lambda (env aux)
    (make-apply)
    (insert-string env)
    (insert-argument)
    (insert-string aux)
    (make-active-begin-from-apply)))

(define make-active-bib
  (lambda (style file-name)
    (make-apply)
    (insert-string "bibliography")
    (insert-argument)
    (insert-string "bib")
    (insert-argument)
    (insert-string style)
    (insert-argument)
    (insert-string file-name)
    (make-active-begin-from-apply)))

(define insert-description
  (lambda (s)
    (make-active-list-item "description" s)))

(define insert-text-item
  (lambda (s)
    (make-active-item-tree (object->tree `(item* ,(string->symbol s))))))

(define make-image
  (lambda (l)
    (eval (cons 'make-postscript l))))

(define set-left-margin
  (lambda (s)
    (make-active-set "left margin" s)))

(define set-right-margin
  (lambda (s)
    (make-active-set "right margin" s)))

(define set-first-indent
  (lambda (s)
    (make-active-set "first indentation" s)))

(define set-last-indent
  (lambda (s)
    (make-active-set "last-indentation" s)))

(define set-interline
  (lambda (s)
    (make-active-set "interline space" s)))

(define set-par-spc
  (lambda (s)
    (make-active-set "interparagraph space" s)))

;; Initialization commands

(define init-page-margins
  (lambda (l r t b)
    (init-env "odd page margin" l)
    (init-env "even page margin" l)
    (init-env "page right margin" r)
    (init-env "page top margin" t)
    (init-env "page bottom margin" b)))

(define init-screen-reduction
  (lambda (l r t b)
    (init-env "reduction page left margin" l)
    (init-env "reduction page right margin" r)
    (init-env "reduction page top margin" t)
    (init-env "reduction page bottom margin" b)))

(define init-page-size
  (lambda (w h p)
    (init-env "page type" "user")
    (init-env "page width" w)
    (init-env "page height" h)
    (init-env "paragraph width" p)
    (init-page-margins "5mm" "5mm" "5mm" "5mm")
    (init-screen-reduction "0cm" "0cm" "0cm" "0cm")))

(define init-text-width
  (lambda (s) (init-env "paragraph width" s)))

(define init-font-size
  (lambda (s) (init-env "font base size" s)))

(define init-dpi
  (lambda (s) (init-env "dpi" s)))

(define init-first-indent
  (lambda (s) (init-env "first indentation" s)))

(define init-interline
  (lambda (s) (init-env "interline space" s)))

(define init-par-spc
  (lambda (s) (init-env "interparagraph space" s)))

(define init-magn
  (lambda (s) (init-env "magnification" s)))

(define other-shrinking-factor
  (lambda (s) (set-shrinking-factor (string->number s))))

;;
;; The File menu
;;

(define file-menu
  '(("new" "<F1>" (new-buffer))
    ("load" "<F2>" (choose-file "Load file" "" 'load-generic-buffer))
    ("save" "<F3>" (save-texmacs-buffer (get-name-buffer)))
    ("save as" "<F4>"
      (choose-file "Save TeXmacs file" "TeXmacs" 'save-texmacs-buffer))
    ("revert buffer" (revert-buffer))
    ---
    (-> "print"
      ("preview with ghostview"
	(begin (print-to-file "$TEXMACS_HOME_PATH/system/preview.ps")
	       (shell "ghostview $TEXMACS_HOME_PATH/system/preview.ps &")))
;;    ("preview with ghostview"
;;	(begin
;;        (print-to-file "$TEXMACS_HOME_PATH/system/preview.ps")
;;	  (shell
;;          "ghostview -antialias $TEXMACS_HOME_PATH/system/preview.ps &")))
;;    ("preview before printing"
;;	(begin (init-screen-reduction "0mm" "0mm" "0mm" "0mm")
;;	       (init-env "show header and footer" "true")
;;	       (init-env "shrinking factor" "10")))
      ---
      ("print all" (print))
      ("print page selection"
	(interactive '("First page:" "Last page:") 'print-pages))
      ("print all to file"
	(interactive '("File name:") 'print-to-file))
      ("print page selection to file"
	(interactive
	  '("File name:" "First page:" "Last page:")
          'print-pages-to-file))
      ---
      ("setup printer"
	(interactive
          '("Printing command:" "Paper type:" "Printer dpi:")
	  'setup-printer)))
    (-> "import"
      ("verbatim" (choose-file "Load verbatim file" "" 'load-verbatim-buffer))
      ("html" (choose-file "Load html file" "html" 'load-html-buffer))
      ("LaTeX" (choose-file "Load LaTeX file" "latex" 'load-latex-buffer)))
    (-> "export"
      ("verbatim" (choose-file "Save verbatim file" "" 'save-verbatim-buffer))
      ("LaTeX" (choose-file "Save LaTeX file" "latex" 'save-latex-buffer))
      ("postscript"
        (choose-file "File postscript file" "postscript" 'export-postscript)))
    ---
    ("open new window" (open-window))
    ("clone window" (clone-window))
    ("load in new window"
      (choose-file "Load file" "" 'load-in-new-window))
    ---
    ("kill buffer"  (kill-buffer))
    ("kill window" (kill-window))
    ("kill TeXmacs"
      (if (exists-unsaved-buffer)
	(interactive
          '("There are unsaved files. Really quit?")
          'quit-TeXmacs-confirm)
	(quit-TeXmacs)))))

;;
;; The Edit menu
;;

(define edit-menu
  '(("copy" "<esc>c" (copy))
    ("cut" "<esc>u" (cut))
    ("clear" "<esc>r" (selection-clear))
    ("paste" "<esc>p" (paste))))

;;
;; The Insert menu
;;

(define session-menu
  '(("shell" (make-session "shell"))
    ("scheme" (make-session "scheme"))
    ("pari" (make-session "pari"))
    ("Macaulay 2" (make-session "Macaulay2"))))

(define text-mode-insert-menu
  '((-> "section"
      ("chapter" (make-apply-arg "chapter"))
      ("section" (make-apply-arg "section"))
      ("subsection" (make-apply-arg "subsection"))
      ("subsubsection" (make-apply-arg "subsubsection"))
      ("appendix" (make-apply-arg "appendix"))
      ("prologue" (make-active-apply "prologue"))
      ("epilogue" (make-active-apply "epilogue"))
      ---
      ("title" (make-apply-arg "title"))
      ("author" (make-apply-arg "author"))
      ("address" (make-apply-arg "address"))
      ("make title" (make-active-apply "maketitle")))
    (-> "environment"
      ("theorem" (make-active-begin "theorem"))
      ("proposition" (make-active-begin "proposition"))
      ("lemma" (make-active-begin "lemma"))
      ("corollary" (make-active-begin "corollary"))
      ("proof" (make-active-begin "proof"))
      ("axiom" (make-active-begin "axiom"))
      ("definition" (make-active-begin "definition"))
      ---
      ("abstract" (make-active-begin "abstract"))
      ("remark" (make-active-begin "remark"))
      ("note" (make-active-begin "note"))
      ("example" (make-active-begin "example"))
      ("exercise" (make-active-begin "exercise"))
      ("warning" (make-active-begin "warning"))
      ---
      ("verbatim" (make-active-begin "verbatim"))
      ("quote" (make-active-begin "quote"))
      ("quotation" (make-active-begin "quotation"))
      ("verse" (make-active-begin "verse")))
    (-> "automatic"
      ("table of contents" (make-active-aux "table-of-contents" "toc"))
      ("bibliography" (interactive
	'("Bibliography style:" "Bibliography file:") 'make-active-bib))
      ("index" (make-active-aux "index" "idx"))
      ("glossary" (make-active-aux "glossary" "gly"))
      ("list of figures" (make-active-aux "list-of-figures" "lof"))
      ("list of tables" (make-active-aux "list-of-tables" "lot")))
    (-> "formula"
      ("formula" "$" (make-active-set "mode" "math"))
      ("equation" (make-active-begin "equation*"))
      ("numbered equation" (make-active-begin "equation"))
      ("equations"
        (begin (make-active-begin "eqnarray*") (make-active-equation))))
    (-> "session" (link session-menu))
    ---
    (-> "itemize"
      ("default" (make-active-list "itemize"))
      ---
      ("minus" (make-active-list "itemize-minus"))
      ("dot" (make-active-list "itemize-dot"))
      ("arrow" (make-active-list "itemize-arrow"))
      ---
      ("new item" (make-active-item "item")))
    (-> "enumerate"
      ("default" (make-active-list "enumerate"))
      ---
      ("1, 2, 3, ..." (make-active-list "enumerate-numeric"))
      ("i, ii, iii, ..." (make-active-list "enumerate-roman"))
      ("I, II, III, ..." (make-active-list "enumerate-Roman"))
      ("a, b, c, ..." (make-active-list "enumerate-alpha"))
      ("A, B, C, ..." (make-active-list "enumerate-Alpha"))
      ---
      ("new number" (make-active-item "item")))
    (-> "description"
      ("default"  (interactive '("First item:") 'insert-description))
      ("new item" (interactive '("Insert item:") 'insert-text-item)))
    (-> "tabular"
      ("new table" (make-split))
      ("separator" (make-format "line separator"))
      ("next line" (make-format "next line")))
    (link mosaic-menu)))

(define symbol-menu
  '((-> "large opening bracket" (tile 8 (link left-delimiter-menu)))
    (-> "large separator" (tile 8 (link middle-delimiter-menu)))
    (-> "large closing bracket" (tile 8 (link right-delimiter-menu)))
    (-> "big operator"
      (tile 8 (link big-operator-menu)))
    ---
    (-> "binary operation"
      (tile 8 (link binary-operation-menu)))
    (-> "binary relation"
      (tile 8 (link binary-relation-menu-1))
      ---
      (tile 8 (link binary-relation-menu-2)))
    (-> "arrow"
      (tile 9 (link horizontal-arrow-menu))
      ---
      (tile 8 (link vertical-arrow-menu))
      ---
      (tile 6 (link long-arrow-menu)))
    (-> "negation"
      ("general negation" "/" (key-press "/"))
      ---
      (tile 6 (link negation-menu)))
    ---
    (-> "greek letter"
      (tile 8 (link lower-greek-menu))
      ---
      (tile 8 (link upper-greek-menu)))
    (-> "miscellaneous"
      (tile 8 (link miscellaneous-symbol-menu)))))

(define math-mode-insert-menu
  '(("fraction" "<esc>F" (make-fraction))
    ("square root" "<esc>S" (make-sqrt))
    ("n-th root" "<esc>R" (make-var-sqrt))
    ("negation" "<esc>N" (make-neg))
    ("tree" "<esc>A" (make-tree))
    ("text" "$" (make-active-set "mode" "text"))
    ("equation" (begin (make-format "next line") (make-active-equation)))
    ---
    (-> "script"
      ("left subscript" "<esc>L_" (make-script #f #f))
      ("left superscript" "<esc>L^" (make-script #t #f))
      ("right subscript" "_" (make-script #f #t))
      ("right superscript" "^" (make-script #t #t))
      ("script below" (make-below))
      ("script above" (make-above)))
    (-> "accent"
      ("tilda" "<esc>~" (make-wide "~"))
      ("hat" "<esc>^" (make-wide "^"))
      ("bar" "<esc>B" (make-wide "<bar>"))
      ("vector" "<esc>V" (make-wide "<vect>"))
      ("check" "<esc>v" (make-wide "<check>"))
      ("breve" "<esc>U" (make-wide "<breve>"))
      ("acute" "<esc>\'" (make-wide "<acute>"))
      ("grave" "<esc>`" (make-wide "<grave>")))
    (link mosaic-menu)
    (-> "symbol" (link symbol-menu))))

(define mosaic-menu
  '((-> "mosaic"
      ("matrix" "<esc>M" (make-matrix))
      ("table" "<esc>T" (make-table))
      ("mosaic" (make-mosaic))
      ---
      (-> "row"
        ("new" (row-insert #t))
        ("delete" (row-delete))
        ("line" (row-line "0.1fn"))
        (-> "position"
          ("top" (row-position "n"))
          ("center" (row-position "c"))
          ("bottom" (row-position "s"))
          ("default" (row-position "0"))))
      (-> "column"
        ("new" (column-insert #t))
        ("delete" (column-delete))
        ("line" (column-line "0.1fn"))
        (-> "position"
          ("left" (column-position "w"))
          ("center" (column-position "c"))
          ("right" (column-position "e"))
          ("default" (column-position "0"))))
      ---
      ("cut" (mosaic-cut))
      (-> "glue"
        ("right" (mosaic-glue "r"))
        ("down" (mosaic-glue "d")))
      (-> "horizontal position"
        ("left" (mosaic-horizontal "w"))
        ("center" (mosaic-horizontal "c"))
        ("right" (mosaic-horizontal "e"))
        ("default" (mosaic-horizontal "0")))
      (-> "vertical position"
        ("top" (mosaic-vertical "n"))
        ("center" (mosaic-vertical "c"))
        ("bottom" (mosaic-vertical "s"))
        ("default" (mosaic-vertical "0")))
      (-> "background color"
        ("none" (mosaic-color "none"))
        ("default" (mosaic-color "black"))))))

(define insert-menu
  '((if (equal? (get-env "mode") "text")
      (link text-mode-insert-menu)
      ---)
    (if (equal? (get-env "mode") "math")
      (link math-mode-insert-menu)
      ---)
    (-> "space"
      ("rigid" (interactive
        '("Horizontal space:" "Base level:" "Top level:") 'make-var-space))
      (-> "horizontal"
        ("stretchable" (interactive '("Horizontal space:") 'make-hspace))
        ("rigid" (interactive '("Horizontal space:") 'make-space))
        ("tab" (make-htab "5mm")))
      (-> "vertical before"
        ("small skip" (make-vspace-before "0.5fn"))
        ("medium skip" (make-vspace-before "1fn"))
        ("big skip" (make-vspace-before "2fn"))
        ("other" (interactive '("Vertical space:") 'make-vspace-before)))
      (-> "vertical after"
        ("small skip" (make-vspace-after "0.5fn"))
        ("medium skip" (make-vspace-after "1fn"))
        ("big skip" (make-vspace-after "2fn"))
        ("other" (interactive '("Vertical space:") 'make-vspace-after))))
    (-> "break"
      ("line break" "<esc>:" (make-format "line break"))
      ("new line" "<esc>;" (make-format "new line"))
      ("no line break" "<esc>/" (make-format "no line break"))
      ("page break" (make-format "page break"))
      ("new page" (make-format "new page"))
      ("no page break before" (make-format "no page break before"))
      ("no page break after" (make-format "no page break after")))
    (-> "indentation flag"
      ("disable indentation before" (make-format "no first indentation"))
      ("enable indentation before" (make-format "enable first indentation"))
      ---
      ("disable indentation after"
        (make-active-assign "no first indentation" "true"))
      ("enable indentation after"
        (make-active-assign "no first indentation" "false")))
    ---
    (-> "link"
      ("label" "<esc>!" (make-label))
      ("reference" "<esc>?" (make-reference))
      ("citation" (make-apply-arg "cite"))
      ("invisible citation" (make-apply-arg "nocite")))
    (-> "specific"
      ("html" (make-specific "html"))
      ("latex" (make-specific "latex"))
      ("tex" (make-specific "tex"))
      ("texmacs" (make-specific "texmacs")))
    (-> "special"
      ("image" (choose-file "Load image" "image" 'make-image))
      ("group" (make-group))
      ("move object" (interactive '("Horizontal:" "Vertical:") 'make-move))
      ("resize object" (interactive
        '("Extend or normal:" "left:" "bottom:" "right:" "top:")
	'make-resize)))))

;;
;; The Text menu
;;

(define font-size-menu
  '(("tiny" (make-active-set "font size" "0.59"))
    ("very small" (make-active-set "font size" "0.71"))
    ("small" (make-active-set "font size" "0.84"))
    ("normal" (make-active-set "font size" "1"))
    ("large" (make-active-set "font size" "1.19"))
    ("very large" (make-active-set "font size" "1.41"))
    ("huge" (make-active-set "font size" "1.68"))
    ("really huge" (make-active-set "font size" "2"))))

(define text-font-menu
  '((-> "name"
      ("roman" (make-active-set "font" "roman"))
      ("pandora" (make-active-set "font" "pandora"))
      ("concrete" (make-active-set "font" "concrete"))
      ---
      (-> "adobe"
	("avant garde" (make-active-set "font" "avant-garde"))
	("bookman" (make-active-set "font" "bookman"))
	("chancellary" (make-active-set "font" "chancellary"))
	("courier" (make-active-set "font" "courier"))
	("dingbat" (make-active-set "font" "dingbat"))
	("helvetica" (make-active-set "font" "helvetica"))
	("new century schoolbook"
          (make-active-set "font" "new-century-schoolbook"))
	("palatino" (make-active-set "font" "palatino"))
	("times" (make-active-set "font" "times")))
      (-> "latin"
        ("calligraphic" (make-active-set "font" "calligraphic"))
        ("capbas" (make-active-set "font" "capbas"))
        ("duerer" (make-active-set "font" "duerer"))
        ("hershey" (make-active-set "font" "hershey"))
        ("italic right" (make-active-set "font shape" "italic-right"))
        ("la" (make-active-set "font" "la"))
        ("messy" (make-active-set "font" "messy"))
        ("optical" (make-active-set "font" "optical"))
        ("pacioli" (make-active-set "font" "pacioli"))
        ("punk" (make-active-set "font" "punk"))
        ("tw#calligraphic" (make-active-set "font" "twcal"))
        ("va" (make-active-set "font" "va")))
      (-> "gothic"
        ("blackletter" (make-active-set "font" "blackletter"))
        ("Euler" (make-active-set "font" "Euler"))
        ("gothic" (make-active-set "font" "gothic"))
        ("old english" (make-active-set "font" "old-english"))
        ("schwell" (make-active-set "font" "schwell"))
        ("suet" (make-active-set "font" "suet"))
        ("swab" (make-active-set "font" "swab")))
      (-> "foreign"
        ;; ("arab" (make-active-set "font" "arab"))
        ("armenian" (make-active-set "font" "armenian"))
	("cyrillic" (make-active-set "font" "cyrillic"))
        ("devangari" (make-active-set "font" "devangari"))
	(-> "georgian"
          ("mxedruli" (make-active-set "font" "mxedruli"))
          ("xucuri" (make-active-set "font" "xucuri")))
        ("greek" (make-active-set "font" "greek"))
        ("hebrew" (make-active-set "font" "hebrew"))
        ("icelandic" (make-active-set "font" "icelandic"))
        ("irish" (make-active-set "font" "irish"))
	;; ("osmanian" (make-active-set "font" "osmanian"))
        ;; ("turkish" (make-active-set "font" "turkish"))
        ;; ("tamil" (make-active-set "font" "tamil"))
        ("thai" (make-active-set "font" "thai"))
        ("vietnamese" (make-active-set "font" "vietnamese")))
      (-> "archaic"
        ("bard" (make-active-set "font" "bard"))
        ("cypriot" (make-active-set "font" "cypriot"))
        ("etruscan" (make-active-set "font" "etruscan"))
        (-> "greek"
          ("4th century bc" (make-active-set "font" "greek4cbc"))
          ("6th century bc" (make-active-set "font" "greek6cbc")))
        ;; ("ogham" (make-active-set "font" "ogham"))
        ("phoenician" (make-active-set "font" "phoenician"))
        (-> "runic"
          ("default" (make-active-set "font" "runic"))
          ("futhark" (make-active-set "font" "runic*"))
          ("futhork" (make-active-set "font" "runic**")))
        ;; ("south arabian" (make-active-set "font" "southarabian"))
        ;; ("syriac" (make-active-set "font" "syriac"))
	("old slavonic" (make-active-set "font" "old-slavonic"))
        ("ugaritic" (make-active-set "font" "ugaritic")))
      (-> "phantasy"
        ;; ("cherokee" (make-active-set "font" "cherokee"))
        ;; ("shavian" (make-active-set "font" "shavian"))
        ("tengwar" (make-active-set "font" "tengwar")))
      (-> "miscellaneous"
        ("dancers" (make-active-set "font" "dancers"))
        ("dingbat" (make-active-set "font" "bbding"))
        ("go" (make-active-set "font" "go"))
        ("iching" (make-active-set "font" "iching"))
        ("karta" (make-active-set "font" "karta"))
        ("klinz" (make-active-set "font" "klinz"))
        ("magic" (make-active-set "font" "magic"))
        ("phonetic" (make-active-set "font" "phonetic"))
        ("tsipa" (make-active-set "font" "tsipa"))
        ("wsuipa" (make-active-set "font" "wsuipa")))
      (-> "X-windows"
        ("times" (make-active-set "font" "x-times"))
        ("courier" (make-active-set "font" "x-courier"))
        ("helvetica" (make-active-set "font" "x-helvetica"))
        ("utopia" (make-active-set "font" "x-utopia"))
        ("lucida" (make-active-set "font" "x-lucida"))))
    (-> "family"
      ("roman" (make-active-set "font family" "rm"))
      ("typewriter" (make-active-set "font family" "tt"))
      ("sans serif" (make-active-set "font family" "ss")))
    (-> "series"
      ("light" (make-active-set "font series" "light"))
      ("medium" (make-active-set "font series" "medium"))
      ("bold" (make-active-set "font series" "bold")))
    (-> "shape"
      ("right" (make-active-set "font shape" "right"))
      ("slanted" (make-active-set "font shape" "slanted"))
      ("italic" (make-active-set "font shape" "italic"))
      ("left slanted" (make-active-set "font shape" "left-slanted"))
      ---
      ("small caps" (make-active-set "font shape" "small-caps"))
      ("proportional" (make-active-set "font shape" "proportional"))
      ("condensed" (make-active-set "font shape" "condensed"))
      ("flat" (make-active-set "font shape" "flat"))
      ("long" (make-active-set "font shape" "long")))
    (-> "size" (link font-size-menu))))

(define math-font-menu
  '((-> "name"
      ("roman" (make-active-set "math font" "roman"))
      ("concrete" (make-active-set "math font" "concrete"))
      ("new roman" (make-active-set "math font" "ENR"))
      ---
      ("adobe" (make-active-set "math font" "adobe"))
      ("Duerer" (make-active-set "math font" "Duerer"))
      ("Euler" (make-active-set "math font" "Euler"))
      (-> "calligraphic"
        ("default" (make-active-set "math font" "cal"))
        ("Euler" (make-active-set "math font" "cal**"))
        ("Ralph Smith's" (make-active-set "math font" "cal*")))
      (-> "blackboard bold"
        ("A.M.S." (make-active-set "math font" "Bbb"))
        ("blackboard math" (make-active-set "math font" "Bbb*"))
        ("blackboard bold" (make-active-set "math font" "Bbb**"))
        ("outlined roman" (make-active-set "math font" "Bbb***"))
        ("double stroke" (make-active-set "math font" "Bbb****"))))
    (-> "family"
      ("roman" (make-active-set "math font family" "mr"))
      ("typewriter" (make-active-set "math font family" "mt"))
      ("sans serif" (make-active-set "math font family" "ms")))
    (-> "series"
      ("light" (make-active-set "math font series" "light"))
      ("medium" (make-active-set "math font series" "medium"))
      ("bold" (make-active-set "math font series" "bold")))
    (-> "shape"
      ("default" (make-active-set "math font shape" "normal"))
      ("right" (make-active-set "math font shape" "right"))
      ("slanted" (make-active-set "math font shape" "slanted"))
      ("italic" (make-active-set "math font shape" "italic"))
      ---
      ("semi-right" (make-active-set "math font shape" "semi-right")))
    (-> "size" (link font-size-menu))))

(define prog-font-menu
  '((-> "name"
      ("roman" (make-active-set "prog font" "roman"))
      ("concrete" (make-active-set "prog font" "concrete"))
      ("pandora" (make-active-set "prog font" "pandora")))
    (-> "family"
      ("roman" (make-active-set "prog font family" "rm"))
      ("typewriter" (make-active-set "prog font family" "tt"))
      ("sans serif" (make-active-set "prog font family" "ss")))
    (-> "series"
      ("medium" (make-active-set "prog font series" "medium"))
      ("bold" (make-active-set "prog font series" "bold")))
    (-> "shape"
      ("default" (make-active-set "prog font shape" "normal"))
      ("right" (make-active-set "prog font shape" "right"))
      ("slanted" (make-active-set "prog font shape" "slanted"))
      ("italic" (make-active-set "prog font shape" "italic")))
    (-> "size" (link font-size-menu))))

(define text-menu
  '((if (equal? (get-env "mode") "text")
      (-> "font" (link text-font-menu)))
    (if (equal? (get-env "mode") "math")
      (-> "font" (link math-font-menu)))
    (if (equal? (get-env "mode") "prog")
      (-> "font" (link prog-font-menu)))
    (-> "color"
      ("black" (make-active-set "color" "black"))
      ("white" (make-active-set "color" "white"))
      ("grey" (make-active-set "color" "grey"))
      ("red" (make-active-set "color" "red"))
      ("blue" (make-active-set "color" "blue"))
      ("yellow" (make-active-set "color" "yellow"))
      ("green" (make-active-set "color" "green"))
      ("orange" (make-active-set "color" "orange"))
      ("magenta" (make-active-set "color" "magenta"))
      ("brown" (make-active-set "color" "brown"))
      ("pink" (make-active-set "color" "pink")))
    (-> "language"
      ("dutch" (make-active-set "language" "dutch"))
      ("english" (make-active-set "language" "english"))
      ("french" (make-active-set "language" "french"))
      ("german" (make-active-set "language" "german"))
      ("romanian" (make-active-set "language" "romanian"))
      ("russian" (make-active-set "language" "russian"))
      ("swedish" (make-active-set "language" "swedish")))
    (if (equal? (get-env "mode") "math")
      ---
      (-> "index level"
        ("normal" (make-active-set "index level" "0"))
        ("script size" (make-active-set "index level" "1"))
        ("script script size" (make-active-set "index level" "2")))
      (-> "formula style"
        ("on" (make-active-set "formula style" "true"))
        ("off" (make-active-set "formula style" "false")))
      (-> "condensed"
        ("on" (make-active-set "math condensed" "true"))
        ("off" (make-active-set "math condensed" "false"))))))

;;
;; The Paragraph menu
;;

(define paragraph-menu
  '((-> "style"
      ("justified" (make-active-set "paragraph mode" "justify"))
      ("left ragged" (make-active-set "paragraph mode" "left"))
      ("centered" (make-active-set "paragraph mode" "center"))
      ("right ragged" (make-active-set "paragraph mode" "right")))
    (-> "hyphenation"
      ("normal" (make-active-set "paragraph hyphenation" "normal"))
      ("professional"
        (make-active-set "paragraph hyphenation" "professional")))
    (-> "margins"
      ("left margin" (interactive '("Left margin:") 'set-left-margin))
      ("right margin" (interactive '("Right margin:") 'set-right-margin))
      ("first indentation"
        (interactive '("First indentation:") 'set-first-indent))
      ("last indentation"
	(interactive '("Last indentation:") 'set-last-indent)))
    (-> "spacing"
      ("interline space"
        (interactive '("Separation between lines:") 'set-interline))
      ("interparagraph space"
	(interactive '("Separation between paragraphs:") 'set-par-spc)))))

;;
;; The Document menu
;;

(define style-menu
  '(("letter" (init-style "letter"))
    ("article" (init-style "article"))
    ("book" (init-style "book"))
    ("seminar" (init-style "seminar"))
    ("browser" (init-style "browser"))
    ("project" (init-style "project"))))

(define use-package-menu
  '(("basic" (init-extra-style "basic"))
    ("list" (init-extra-style "list"))
    ("theorem" (init-extra-style "theorem"))
    ("program" (init-extra-style "program"))
    ("automatic" (init-style "automatic"))))
      
(define document-menu
  '((-> "style"
      ("none" (init-style "none"))
      ---
      (link style-menu)
      ---
      ("other" (interactive '("Document style:") 'init-style)))
    (-> "use package"
      (link use-package-menu)
      ---
      ("other" (interactive '("Use package:") 'init-extra-style)))
    (-> "project"
      ("attach" (interactive
        '("Attach buffer to which project?") 'project-attach))
      ("detach" (project-detach)))
    ---
    (-> "font"
      (-> "text font"
        ("default" (init-default "font"))
	---
        ("roman" (init-env "font" "roman"))
        ("pandora" (init-env "font" "pandora"))
        ("concrete" (init-env "font" "concrete"))
        ("cyrillic" (init-env "font" "cyrillic"))
	---
        ("bookman" (init-env "font" "bookman"))
        ("courier" (init-env "font" "courier"))
        ("helvetica" (init-env "font" "helvetica"))
        ("palatino" (init-env "font" "palatino"))
        ("times" (init-env "font" "times"))
        ---
        ("lucida" (init-env "font" "x-lucida"))
        ("utopia" (init-env "font" "x-utopia")))
      (-> "math font"
        ("default" (init-default "math font"))
	---
        ("roman" (init-env "math font" "roman"))
        ("concrete" (init-env "math font" "concrete"))
        ("Euler new roman" (init-env "math font" "ENR"))
        ("adobe" (init-env "math font" "adobe")))
      (-> "prog font"
        ("default" (init-default "prog font"))
	---
        ("roman" (init-env "prog font" "roman"))
        ("pandora" (init-env "prog font" "pandora"))
        ("concrete" (init-env "prog font" "concrete"))
        ("times" (init-env "prog font" "times")))
      ---
      (-> "size"
        ("default" (init-default "font base size"))
	---
        ("8" (init-env "font base size" "8"))
        ("9" (init-env "font base size" "9"))
        ("10" (init-env "font base size" "10"))
        ("11" (init-env "font base size" "11"))
        ("12" (init-env "font base size" "12"))
        ("14" (init-env "font base size" "14"))
        ---
        ("other" (interactive '("Font size:") 'init-font-size)))
      (-> "dpi"
        ("default" (init-default "dpi"))
	---
        ("150" (init-env "dpi" "150"))
        ("200" (init-env "dpi" "200"))
        ("300" (init-env "dpi" "300"))
        ("400" (init-env "dpi" "400"))
        ("600" (init-env "dpi" "600"))
        ("800" (init-env "dpi" "800"))
        ("1200" (init-env "dpi" "1200"))
        ---
        ("other" (interactive '("Font dpi:") 'init-dpi))))
    (-> "language"
      ("default" (init-default "language"))
      ---
      ("dutch" (init-env "language" "dutch"))
      ("english" (init-env "language" "english"))
      ("french" (init-env "language" "french"))
      ("german" (init-env "language" "german"))
      ("romanian" (init-env "language" "romanian"))
      ("russian" (init-env "language" "russian"))
      ("swedish" (init-env "language" "swedish")))
    (-> "paragraph"
      (-> "style"
        ("default" (init-default "paragraph mode"))
	---
        ("justified" (init-env "paragraph mode" "justify"))
        ("left ragged" (init-env "paragraph mode" "left"))
        ("centered" (init-env "paragraph mode" "center"))
        ("right ragged" (init-env "paragraph mode" "right")))
      (-> "hyphenation"
        ("default" (init-default "paragraph hyphenation"))
	---
        ("normal" (init-env "paragraph hyphenation" "normal"))
        ("professional" (init-env "paragraph hyphenation" "professional")))
      (-> "margins"
        ("default" (init-default "first indentation"))
        ---
        ("first indentation"
          (interactive '("First indentation:") 'init-first-indent))
        ("last indentation"
          (interactive '("Last indentation:") 'init-last-indent)))
      (-> "spacing"
        ("default" (begin
          (init-default "interline space")
          (init-default "interparagraph space")))
	---
        ("interline space"
          (interactive '("Separation between lines:") 'init-interline))
        ("interparagraph space"
	  (interactive '("Separation between paragraphs:") 'init-par-spc))))
    (-> "page"
      (-> "type"
        ("default" (begin
	  (init-default "page medium")
	  (set-page-parameters)))
	---
        ("paper" (set-page-medium "paper"))
        ("papyrus" (set-page-medium "papyrus"))
        ("automatic" (set-page-medium "automatic")))
      (-> "size"
        ("default" (begin
	  (init-default "page type")
	  (set-page-parameters)))
	---
        ("a3" (set-page-type "a3"))
        ("a4" (set-page-type "a4"))
        ("a5" (set-page-type "a5"))
        ("b4" (set-page-type "b4"))
        ("b5" (set-page-type "b5"))
        ("b6" (set-page-type "b6"))
        ("letter" (set-page-type "letter"))
        ("legal" (set-page-type "legal"))
        ("executive" (set-page-type "executive"))
        ("lecture note" (set-page-type "lecture note"))
	---
        ("other"
	  (interactive '("Page width:" "Page height:" "Text width:")
                       'init-page-size)))
      (-> "orientation"
        ("default" (begin
	  (init-default "page orientation")
	  (set-page-parameters)))
	---
        ("portrait" (set-page-orientation "portrait"))
        ("landscape" (set-page-orientation "landscape")))
      (-> "layout"
        ("default" (begin
          (init-default "odd page margin")
          (init-default "even page margin")
          (init-default "page right margin")
          (init-default "page top margin")
          (init-default "page bottom margin")
          (init-default "paragraph width")))
	---
        ("set margins"
	  (interactive '("Left margin:" "Right margin:"
                         "Top margin:" "Bottom margin:") 'init-page-margins))
        ("set text width"
	  (interactive '("Text width:") 'init-text-width)))
      (-> "screen layout"
        ("default" (begin
          (init-default "reduction page left margin")
          (init-default "reduction page right margin")
          (init-default "reduction page top margin")
          (init-default "reduction page bottom margin")))
	---
        ("as on paper"
	  (begin (init-screen-reduction "0mm" "0mm" "0mm" "0mm")
	         (init-env "show header and footer" "true")))
        ("reduce margins" (interactive
          '("Reduce left margin by:"
            "Reduce right margin by:"
            "Reduce top margin by:"
	    "Reduce bottom margin by:") 'init-screen-reduction))))
    ---
    (-> "update"
      ("all" (begin (generate-all-aux) (update-buffer)))
      ---
      ("buffer" (update-buffer))
      ("table of contents" (generate-aux "table-of-contents"))
      ("bibliography" (generate-aux "bibliography")))))

;;
;; The Project menu
;;

(define project-menu
  '(("compile buffer" (project-compile-buffer))
    ("compile project" (project-compile-all))
    ---
    (link project-buffer-menu)))

;;
;; The Options menu
;;

(define options-menu
  '((-> "mode"
      ("preamble" (init-env "preamble" "true"))
      ("normal" (init-env "preamble" "false")))
    (-> "language"
      ("dutch" (set-output-language "dutch"))
      ("english" (set-output-language "english"))
      ("french" (set-output-language "french"))
      ("german" (set-output-language "german"))
      ("romanian" (set-output-language "romanian"))
      ("russian" (set-output-language "russian"))
      ("swedish" (set-output-language "swedish"))
      ---
      ("other" (interactive '("Language:") 'set-output-language)))
    (-> "magnification"
      ("default" (init-default "magnification"))
      ---
      ("0.7" (init-env "magnification" "0.7"))
      ("0.8" (init-env "magnification" "0.8"))
      ("1" (init-env "magnification" "1"))
      ("1.2" (init-env "magnification" "1.2"))
      ("1.4" (init-env "magnification" "1.4"))
      ("1.7" (init-env "magnification" "1.7"))
      ("2" (init-env "magnification" "2"))
      ---
      ("other" (interactive '("Magnification:") 'init-magn)))
    (-> "shrinking factor"
      ("default" (set-shrinking-factor 5))
      ---
      ("1" (set-shrinking-factor 1))
      ("2" (set-shrinking-factor 2))
      ("3" (set-shrinking-factor 3))
      ("4" (set-shrinking-factor 4))
      ("5" (set-shrinking-factor 5))
      ("7" (set-shrinking-factor 7))
      ("10" (set-shrinking-factor 10))
      ---
      ("other" (interactive '("Shrinking factor:") 'other-shrinking-factor)))
    (-> "show header and footer"
      ("default" (init-default "show header and footer"))
      ---
      ("on" (init-env "show header and footer" "true"))
      ("off" (init-env "show header and footer" "false")))
    (-> "miscellaneous"
      ("execute system command"
        (interactive '("Command:") 'system))
      ("evaluate scheme expression"
        (interactive '("Command:") 'TeXmacs-eval)))))

;;
;; The Help menu
;;

(define help-menu
  '(("welcome" (load-help-buffer "help/welcome"))
    ---
    ("introduction" (load-help-buffer "help/introduction"))
    ("keyboard" (load-help-buffer "help/keyboard"))
    ("styles" (load-help-buffer "help/styles"))
    ("advanced" (load-help-buffer "help/advanced"))
    ("latex" (load-help-buffer "help/compatibility"))
    ("scheme" (load-help-buffer "help/scheme"))
    ("interface" (load-help-buffer "help/interface"))
    ---
    (-> "about"
      ("about" (load-help-buffer "help/about"))
      ("GNU#licence" (load-verbatim-buffer "$TEXMACS_PATH/LICENCE")))
    (-> "implementation"
      ("architecture" (load-help-buffer "source/general"))
      ---
      ("basic types" (load-help-buffer "source/basic"))
      ("graphical interface" (load-help-buffer "source/window"))
      ---
      ("known bugs" (load-help-buffer "source/bugs")))
    (-> "projects"
      ("past changes" (load-help-buffer "projects/changes"))
      ("future changes" (load-help-buffer "projects/tochange"))
      ("other projects" (load-help-buffer "projects/projects")))
    (-> "help me"
      ("please" (load-help-buffer "projects/helpme")))))

;;
;; The TeXmacs main menu
;;

(define texmacs-menu
  '((=> "Buffer" (link buffer-menu))
    (=> "File" (link file-menu))
    (=> "Edit" (link edit-menu))
    (=> "Insert" (link insert-menu))
    (=> "Text" (link text-menu))
    (=> "Paragraph" (link paragraph-menu))
    (=> "Document" (link document-menu))
    (if (project-attached)
      (=> "Project" (link project-menu)))
    (=> "Options" (link options-menu))
    (=> "Help" (link help-menu))))

(define texmacs-popup-menu
  '(ver-menu
    (-> "Buffer" (link buffer-menu))
    (-> "File" (link file-menu))
    ---
    (-> "Edit" (link edit-menu))
    (-> "Insert" (link insert-menu))
    (-> "Text" (link text-menu))
    (-> "Paragraph" (link paragraph-menu))
    (-> "Document" (link document-menu))
    (if (project-attached)
      (=> "Project" (link project-menu)))
    ---
    (-> "Help" (link help-menu))))
